@@ -33,13 +33,24 @@ pp = Preprocessor(data_io, data_aug=None, batch_size=1, subfunctions=sf,
 
 from miscnn.neural_network.model import Neural_Network
 model = Neural_Network(preprocessor=pp)
+
+from miscnn.evaluation.cross_validation import split_folds, run_fold
+split_folds(indices_list[0:3], k_fold=3)
+
+for i in range(0,3):
+    print("Running fold:", str(i))
+    run_fold(0, model)
+
 # model.train(indices_list[2:4], epochs=2, iterations=5, callbacks=[])
 
 # model.evaluate(indices_list[0:1], indices_list[1:2], epochs=2, iterations=5)
 
-pred = model.predict(indices_list[2:3], direct_output=True)
+# pred = model.predict(indices_list[2:3], direct_output=True)
+
+# from miscnn.evaluation.cross_validation import cross_validation
+# cross_validation(indices_list[0:3], model, k_fold=3, epochs=3, iterations=10,
+#                  draw_figures=True, run_detailed_evaluation=False)
 
-#
 # import numpy as np
 # print(np.asarray(pred).shape)
 
@@ -104,10 +115,6 @@ pred = model.predict(indices_list[2:3], direct_output=True)
 # history = model.evaluate(training_samples=[indices_list[0]], validation_samples=[indices_list[1]],
 #                          iterations=10)
 
-# from miscnn.evaluation.cross_validation import cross_validation
-# cross_validation(indices_list[0:3], model, k_fold=3, epochs=3, iterations=10,
-#                  draw_figures=True, run_detailed_evaluation=False)
-
 # from miscnn.evaluation.split_validation import split_validation
 # split_validation(indices_list[0:7], model, percentage=0.2, epochs=3, iterations=10)
 
