@@ -1,6 +1,6 @@
 #==============================================================================#
 #  Author:       Dominik Müller                                                #
-#  Copyright:    2019 IT-Infrastructure for Translational Medical Research,    #
+#  Copyright:    2020 IT-Infrastructure for Translational Medical Research,    #
 #                University of Augsburg                                        #
 #                                                                              #
 #  This program is free software: you can redistribute it and/or modify        #
@@ -49,7 +49,7 @@ class Architecture(Abstract_Architecture):
     #---------------------------------------------#
     #                Initialization               #
     #---------------------------------------------#
-    def __init__(self, n_filters=32, depth=4, activation='sigmoid',
+    def __init__(self, n_filters=32, depth=4, activation='softmax',
                  batch_normalization=True):
         # Parse parameter
         self.n_filters = n_filters
