@@ -1,6 +1,6 @@
 #==============================================================================#
 #  Author:       Dominik Müller                                                #
-#  Copyright:    2019 IT-Infrastructure for Translational Medical Research,    #
+#  Copyright:    2020 IT-Infrastructure for Translational Medical Research,    #
 #                University of Augsburg                                        #
 #                                                                              #
 #  This program is free software: you can redistribute it and/or modify        #
@@ -195,6 +195,8 @@ class Preprocessor:
                                     window=self.patch_shape,
                                     overlap=self.patchwise_overlap,
                                     three_dim=self.data_io.interface.three_dim)
+        # For fullimages remove the batch axis
+        else : prediction = np.squeeze(prediction, axis=0)
         # Transform probabilities to classes
         prediction = np.argmax(prediction, axis=-1)
         # Run Subfunction postprocessing on the prediction
